const express = require('express');
const cors = require('cors');
const corsOptions = require('./config/corsConfig');
const upload = require('./middlewares/uploadMiddleware');
const newsRoutes = require('./routes/newsRoutes');
const client = require('./config/db');


const app = express();

app.use(cors(corsOptions));
app.use(express.json());
app.use('/uploads', express.static('uploads'));

app.use('/api/news', newsRoutes);

app.post('/api/upload', upload.single('image'), (req, res) => {
  if (!req.file) return res.status(400).json({ error: 'No file uploaded' });
  res.json({ relativePath: `/uploads/${req.file.filename}` });
});

app.get('/', (req, res) => res.send('Krishi Mongo Server is Running'));

async function run() {
  try {
    await client.connect();
    console.log('Connected to MongoDB');
  } catch (error) {
    console.error('Error connecting to MongoDB:', error);
  }
}

run().catch(console.dir);

module.exports = app;
