const { ObjectId } = require('mongodb');
const client = require('../config/db');
const newsCollection = client.db('krishiMongoDB').collection('newsAPI');

//News Model
const { News } = require('../models');


exports.getAllNews = async (req, res) => {
  try {
    const result = await newsCollection.aggregate([
      { $addFields: { dateAsDate: { $toDate: "$date" } } },
      { $sort: { dateAsDate: -1 } }
    ]).toArray();
    res.send(result);
  } catch (error) {
    res.status(500).send({ error: 'Failed to fetch news' });
  }
};


exports.getNewsById = async (req, res) => {
  try {
    const result = await newsCollection.findOne({ _id: new ObjectId(req.params.id) });
    result ? res.send(result) : res.status(404).send({ error: 'News not found' });
  } catch (error) {
    res.status(500).send({ error: 'Error fetching news' });
  }
};

exports.createNews = async (req, res) => {
  try {
    const result = await newsCollection.insertOne(req.body);
    res.send({ insertedId: result.insertedId, ...result });
  } catch (error) {
    res.status(500).send({ error: 'Failed to create news' });
  }
};

exports.deleteNews = async (req, res) => {
  try {
    const result = await newsCollection.deleteOne({ _id: new ObjectId(req.params.id) });
    res.status(result.deletedCount ? 200 : 404).json({
      message: result.deletedCount ? "News deleted successfully" : "News not found"
    });
  } catch (error) {
    res.status(500).json({ error: 'Failed to delete news' });
  }
};
